/*
 * SPDX-License-Identifier: LGPL-3.0-or-later
 * SPDX-FileCopyrightText: 2020 Intevation GmbH <https://intevation.de>
 * Funded by: ETHZ
 */
import QtQuick 2.12
import QtQuick.Window 2.12
import QtQuick.Controls 2.12

//Dialog showing infos about the application
Dialog {
    x: 100
    y: 100
    width: 600
    height: 300
    modal: true
    focus: true
    closePolicy: Popup.CloseOnEscape | Popup.CloseOnPressOutsideParent
    standardButtons: Dialog.Ok

    Component.onCompleted: {
        standardButton(Dialog.Ok).text = qsTr("Ok")
    }

    contentItem: Pane {
        anchors.fill: parent
        anchors.margins: 0
        Label {
            id: aboutText
            text: qsTr("About Text")
            verticalAlignment: Text.AlignVCenter
            anchors.left: parent.left
            anchors.leftMargin: 10
            anchors.top: parent.top
            anchors.topMargin: 10
            font.pixelSize: 12
        }
        Label {
            id: licenseText
            text: qsTr("This application as complete package is Free Software under
GNU Lesser General Public License v3.0 v >= 3.0 without warranty.")
            anchors.top: aboutText.bottom
            anchors.left: parent.left
            anchors.margins: 10
            font.pixelSize: 12
        }

        Label {
            id: copyRightText
            anchors.top: licenseText.bottom
            anchors.left: parent.left
            anchors.margins: 10
            font.pixelSize: 12
            text: qsTr("© 2020 Intevation GmbH")
            Label {
                id: copyRightUrl
                anchors.left: parent.right
                anchors.leftMargin: 3
                property var url: "https://intevation.de"
                text: '<html><a href="' + url + '">&lt;' + url + '&gt;</a></html>'
                font.pixelSize: 12
                MouseArea {
                    anchors.fill: parent
                    cursorShape: Qt.PointingHandCursor
                    onClicked: Qt.openUrlExternally(parent.url)
                }
            }
        }

        Label {
            id: fundedByText
            anchors.top: copyRightText.bottom
            anchors.left: parent.left
            anchors.margins: 10
            text: qsTr("Funded by Eidgenössische Technische Hochschule Zürich")
            font.pixelSize: 12

            Label {
                id: fundedByUrl
                anchors.left: parent.right
                anchors.leftMargin: 3
                anchors.topMargin: 10
                property var url: "https://ethz.ch/"
                text: '<html><a href="' + url + '">&lt;' + url + '&gt;</a></html>'
                font.pixelSize: 12
                MouseArea {
                    anchors.fill: parent
                    cursorShape: Qt.PointingHandCursor
                    onClicked: Qt.openUrlExternally(parent.url)
                }
            }
        }

        Label {
            id: sourceRepoText
            anchors.top: fundedByText.bottom
            anchors.left: parent.left
            anchors.margins: 10
            text: qsTr("Source code repository:")
            font.pixelSize: 12
            Label {
                id: sourceRepoUrl
                anchors.left: parent.right
                anchors.topMargin: 10
                anchors.leftMargin: 10
                property var url: "https://heptapod.host/intevation/ethz-cups-config-application"
                text: '<html><a href="' + url + '">' + url + '</a></html>'
                font.pixelSize: 12
                MouseArea {
                    anchors.fill: parent
                    cursorShape: Qt.PointingHandCursor
                    onClicked: Qt.openUrlExternally(parent.url)
                }
            }
        }

        Grid {
            id: versionGrid
            columns: 2
            columnSpacing: 10

            anchors.top: sourceRepoText.bottom
            anchors.topMargin: 10
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 10
            anchors.left: parent.left
            anchors.leftMargin: 10
            Label {
                id: versionLabel
                text: qsTr("Version")
                font.pixelSize: 12
            }
            Label {
                id: versionText
                text: controller.getVersion()
                font.pixelSize: 12
            }
            Label {
                id: commitLabel
                visible: commitText.text !== ""
                text: qsTr("Commit")
                font.pixelSize: 12
            }
            Label {
                id: commitText
                visible: commitText.text !== ""
                text: controller.getCommitHash()
                font.pixelSize: 12
            }
            Label {
                id: buildTimeLabel
                text: qsTr("Built at")
                font.pixelSize: 12
            }
            Label {
                id: buildTimeText
                text: controller.getBuildTime()
                font.pixelSize: 12
            }
        }
    }
}
