/*
 * SPDX-License-Identifier: LGPL-3.0-or-later
 * SPDX-FileCopyrightText: 2020 Intevation GmbH <https://intevation.de>
 * Funded by: ETHZ
 */
#include "controller.h"

#include <QJSEngine>

Controller::Controller(QObject *parent) : QObject(parent) {
    cfg = ConfigUtility::getInstance();
    cupsUtility = new CupsUtility();
    smbUtility = new SMBUtility();
}

void Controller::reloadCfg() {
    cfg->reloadCfg();
}

bool Controller::saveConfig() {
    cfg->saveUserCfg();
    return true;
}

QString Controller::getConfigOption(QString key) {
    std::string value = cfg->getCfgOpt(key.toStdString());
    return QString("%1").arg(value.c_str());
}

QString Controller::getBuildTime() {
    return QString("%1").arg(BUILD_TIME);
}

QString Controller::getCommitHash() {
    return QString("%1").arg(HG_COMMIT);
}

QString Controller::getDriverPath() {
    return QString("%1").arg(cfg->getDriverPath().c_str());
}

QString Controller::getPrinterListSmbUri(bool includeFile) {
    return QString("%1").arg(smbUtility->getPrinterListSmbURI(includeFile).c_str());
}

QString Controller::getDriverSmbUri(bool includeFile) {
    return QString("%1").arg(smbUtility->getDriverSmbUri(includeFile).c_str());
}

QString Controller::getSmbUri(QString host, QString share, QString file) {
    return QString("%1").arg(smbUtility->getSmbURI(host.toStdString(), share.toStdString(), file.toStdString()).c_str());
}

QString Controller::getVersion() {
    return QString("%1").arg(APPLICATION_VERSION);
}

bool Controller::isDriverLoaded() {
    return cfg->checkDriverFile();
}

bool Controller::selfCheck() {
    QString errors = "";
    try {
        cupsUtility->selfCheck();
    } catch (PrinterInstallException* pie) {
        errors = pie->what();
    }
    try {
        smbUtility->selfCheck();
    } catch (SMBException* se) {
        if (errors.length() > 0) {
            errors += ";";
        }
        errors += se->what();
    }

    if (errors.length() > 0) {
        qjsEngine(this)->throwError(errors);
        return false;
    }
    return true;
}

bool Controller::setConfigOption(QString key, QString value) {
    try {
        cfg->setCfgOPt(key.toStdString(), value.toStdString());
    } catch (ConfigException*) {
        return false;
    }
    return true;
}

QString Controller::getCfgNameUiTheme() {
    return QString("%1").arg(cfg->CFG_NAME_UI_THEME.c_str());
}

QString Controller::getCfgDriverHost() {
    return QString("%1").arg(cfg->CFG_NAME_DRIVER_HOST.c_str());
}

QString Controller::getCfgDriverShare() {
    return QString("%1").arg(cfg->CFG_NAME_DRIVER_SHARE.c_str());
}

QString Controller::getCfgDriverFile() {
    return QString("%1").arg(cfg->CFG_NAME_DRIVER_FILE.c_str());
}

QString Controller::getCfgDriverLastRefresh() {
    return QString("%1").arg(cfg->CFG_NAME_DRIVER_LAST_REFRESH.c_str());
}

QString Controller::getCfgValueThemeLight() {
    return QString("%1").arg(cfg->CFG_VALUE_THEME_LIGHT.c_str());
}

QString Controller::getCfgValueThemeDark() {
    return QString("%1").arg(cfg->CFG_VALUE_THEME_DARK.c_str());
}

QString Controller::getCfgValueLangAuto() {
    return QString("%1").arg(cfg->CFG_VALUE_LANG_AUTO.c_str());
}

QString Controller::getCfgNameSmbHost() {
    return QString("%1").arg(cfg->CFG_NAME_SMB_HOST.c_str());
}

QString Controller::getCfgNameSmbShare() {
    return QString("%1").arg(cfg->CFG_NAME_SMB_SHARE.c_str());
}

QString Controller::getCfgNameSmbFile() {
    return QString("%1").arg(cfg->CFG_NAME_SMB_FILE.c_str());
}

QString Controller::getCfgNameUiLang() {
    return QString("%1").arg(cfg->CFG_NAME_UI_LANG.c_str());
}
