/*
 * SPDX-License-Identifier: LGPL-3.0-or-later
 * SPDX-FileCopyrightText: 2020 Intevation GmbH <https://intevation.de>
 * Funded by: ETHZ
 */
#include "cupsutility.h"

#include <iostream>
#include <sstream>
#include <syscall.h>

#include <QProcess>
#include <QStringList>

#include <QDebug>
CupsUtility::CupsUtility() {}

bool CupsUtility::addSmbPrinter(PrinterModel &printer) {
    return addSmbPrinter(printer, "");
}

bool CupsUtility::addSmbPrinter(PrinterModel &printer, std::string driver) {

    QProcess proc;
    proc.setProcessChannelMode(QProcess::MergedChannels);
    QStringList args;
    std::stringstream printerUriStream;

    if (printer.getServer().find("smb://") != 0) {
        printerUriStream << "smb://";
    }
    printerUriStream << printer.getServer()
                     << "/" << printer.getName();

    std::string cmdString = getCmd(printer, driver);
    std::cout << "Adding printer:" << std::endl;
    std::cout << cmdString << std::endl;

    args << "-p" << QString::fromStdString(printer.getName())
         << "-E"
         << "-m" << QString::fromStdString(printer.getDriver())
         << "-v" << QString::fromStdString(printerUriStream.str());
    if (driver.length() > 0) {
        args << "-P" << QString::fromStdString(driver);
    }
    args << QString("%1").arg(printer.getOpts().c_str()).split(QRegExp("\\s+"), QString::SkipEmptyParts);
    qDebug() << "ArgList: " << args;
    proc.start(QString::fromStdString(CMD), args);
    if (!proc.waitForStarted()) {
        return false;
    }
    proc.waitForFinished();
    QString output(proc.readAllStandardOutput());
    bool result = proc.exitCode() == 0;
    proc.close();
    if (!result) {
        throw new PrinterInstallException(output.toStdString());
    }
    return true;
}

std::string CupsUtility::getCmd(PrinterModel &printer) {
    return getCmd(printer, "");
}

std::string CupsUtility::getCmd(PrinterModel &printer, std::string driver) {
    std::stringstream printerUriStream;
    if (printer.getServer().find("smb://") != 0) {
        printerUriStream << "smb://";
    }
    printerUriStream << printer.getServer()
                     << "/" << printer.getName();


    std::stringstream cmdStream;
    cmdStream << CMD << " "
              << "-p '" << printer.getName() << "' "
              << "-E" << " "
              << "-m '" << printer.getDriver() << "' "
              << "-v '" << printerUriStream.str() << "' ";
    if (driver.length() > 0) {
        cmdStream << " -P '" << driver << "' ";
    }
    cmdStream << printer.getOpts();

    std::string cmdString = cmdStream.str();
    return cmdString;
}

bool CupsUtility::selfCheck() {
    QDebug debug = qDebug();
    debug << "CupsUtility self check...";
    QProcess proc;
    proc.start(QString::fromStdString(CMD));
    if (!proc.waitForStarted()) {
        debug << "failed";
        throw new PrinterInstallException("Could not find lpadmin binary");
    }
    proc.waitForFinished();
    debug << "passed";
    return true;
}
