/*
 * SPDX-License-Identifier: LGPL-3.0-or-later
 * SPDX-FileCopyrightText: 2020 Intevation GmbH <https://intevation.de>
 * Funded by: ETHZ
 */

#ifndef CUPSUTIL_H
#define CUPSUTIL_H

#include <string>

#include "printermodel.h"

/**
 * @brief Class providing functions to add a printers
 */
class CupsUtility {
public:
    CupsUtility();

    /**
     * @brief Add a smb printer using lpadmin
     * @param printer Printer to add
     * @return True if added successfully, else false
     */
    bool addSmbPrinter(PrinterModel &printer);

    /**
     * @brief Add a smb printer using lpadmin
     * @param printer Printer to add
     * @param driver Driver to use
     * @return True if added successfully, else false
     */
    bool addSmbPrinter(PrinterModel &printer, std::string driver);

    /**
     * @brief Create a cmd to add a printer using lpadmin     *
     * @param printer Printer to add
     * @return Cmd as string
     */
    std::string getCmd(PrinterModel &printer);

    /**
     * @brief Create a cmd to add a printer using lpadmin     *
     * @param printer Printer to add
     * @param driver Driver to use
     * @return Cmd as string
     */
    std::string getCmd(PrinterModel &printer, std::string driver);

    /**
     * @brief Check if lpadmin binary is available
     * @throws PrinterInstallException* If check failed
     * @return True if passed
     */
    bool selfCheck();

private:
    const std::string CMD = "lpadmin";
};

class PrinterInstallException: public std::exception {
private:
    std::string message;
public:
    explicit PrinterInstallException(const std::string& message) {
        this->message = message;
    };
    const char* what() const noexcept override {
        return message.c_str();
    }
};

#endif // CUPSUTIL_H
