/*
 * SPDX-License-Identifier: LGPL-3.0-or-later
 * SPDX-FileCopyrightText: 2020 Intevation GmbH <https://intevation.de>
 * Funded by: ETHZ
 */

#ifndef PRINTERMODEL_H
#define PRINTERMODEL_H

#include <regex>
#include <string>

/**
 * @brief Class modeling a printer
 */
class PrinterModel {
public:
    PrinterModel(int index, std::string name, std::string server, std::string location,
                 std::string driver, std::string format, std::string color,
                 std::string duplex, std::string staple, std::string punch,
                 std::string booklet, std::string scanner, std::string opts,
                 std::string comment);

    int getIndex();
    std::string getName();
    std::string getServer();
    std::string getLocation();
    std::string getDriver();
    std::string getFormat();
    bool getColor();
    bool getDuplex();
    bool getStaple();
    bool getPunch();
    bool getBooklet();
    std::string getScanner();
    std::string getOpts();
    std::string getComment();

    /**
     * @brief Get the value at the given index as string
     * @param index Index
     * @return Value as string
     */
    std::string getAtIndexAsStr(int index);

    /**
     * @brief Check if printer fields match the given regex
     * @param regex Regex to check for
     * @return True if printer matches
     */
    bool matches(const std::regex regex);

private:
    int index;
    std::string name;
    std::string server;
    std::string location;
    std::string driver;
    std::string format;
    bool color;    
    bool duplex;
    bool staple;
    bool punch;
    bool booklet;
    std::string scanner;
    std::string opts;
    std::string comment;
};

#endif // PRINTERMODEL_H
