/*
 * SPDX-License-Identifier: LGPL-3.0-or-later
 * SPDX-FileCopyrightText: 2020 Intevation GmbH <https://intevation.de>
 * Funded by: ETHZ
 */

#ifndef TRANSLATOR_H
#define TRANSLATOR_H

#include <QObject>
#include <QQmlApplicationEngine>
#include <QTranslator>

/**
 * @brief Utility class to switch the application language
 */
class Translator : public QObject {
    Q_OBJECT
public:
    explicit Translator(QObject *parent = nullptr);

    void setEngine(QQmlApplicationEngine* engine);

    /**
     * @brief Switch application language
     * @param locale Locale string, e.g. "en_US"
     */
    Q_INVOKABLE void switchLanguage(QString locale);

    /**
     * @brief Switch application language
     * @param locale Locale string, e.g. "en_US"
     */
    void switchLanguage(std::string locale);

private:
    /**
     * @brief de_CH translator
     */
    QTranslator *de_CH;

    /**
     * @brief en_US Translator
     */
    QTranslator *en_US;

    /**
     * @brief autoLang Translator
     */
    QTranslator *autoLang;

    /**
     * @brief Application engine
     */
    QQmlApplicationEngine *engine;

    /**
     * @brief Map storing translator instances
     */
    std::map<std::string, QTranslator*> translators;

    /**
     * @brief Current translator
     */
    QTranslator* current;

    /**
     * @brief Update the system locale used by the auto setting
     */
    void updateSystemLocale();

signals:

};

#endif // TRANSLATOR_H
